@@ -109,8 +109,8 @@ glmm.wald <- function(fixed, data = parent.frame(), kins = NULL, id, random.slop
                         } else stop("Error: method.optim \"Brent\" can only be applied to unrelated individuals in longitudinal data analysis.")
                 } else {
                         if(method.optim != "AI") kins[[length(kins) + 1]] <- diag(length(unique(data[,id])))
-                        else if(length(kins) > 0) kins[[length(kins) + 1]] <- as(diag(length(unique(data[, id]))), "sparseMatrix")
-                        else kins <- list(kins1 = as(diag(length(unique(data[, id]))), "sparseMatrix"))
+                        else if(length(kins) > 0) kins[[length(kins) + 1]] <- Diagonal(n = length(unique(data[idx, id])))
+                        else kins <- list(kins1 = Diagonal(n = length(unique(data[idx, id]))))
                         rownames(kins[[length(kins)]]) <- colnames(kins[[length(kins)]]) <- unique(data[, id])
                 }
         } else if(!is.null(random.slope)) stop("Error: \"random.slope\" must be used for longitudinal data with duplicated \"id\".")
